@@ -12,6 +12,8 @@
 #include <vector>
 
 #include "glaze/concepts/container_concepts.hpp"
+#include "glaze/core/array_apply.hpp"
+#include "glaze/core/constraint.hpp"
 #include "glaze/core/context.hpp"
 #include "glaze/core/feature_test.hpp"
 #include "glaze/core/meta.hpp"
@@ -158,7 +160,7 @@ namespace glz
       basic_raw_json() = default;
 
       template <class T>
-         requires(!std::same_as<std::decay_t<T>, basic_raw_json>)
+         requires(!std::same_as<std::decay_t<T>, basic_raw_json> && std::constructible_from<string_type, T>)
       basic_raw_json(T&& s) : str(std::forward<T>(s))
       {}
 
@@ -225,12 +227,12 @@ namespace glz
    // this concept requires that T is a writeable string. It can be resized, appended to, or assigned to
    template <class T>
    concept string_t = str_t<T> && !string_view_t<T> &&
-                      (has_assign<T> || (resizable<T> && has_data<T>) || has_append<T>)&&!is_static_string<T>;
+                      (has_assign<T> || (resizable<T> && has_data<T>) || has_append<T>) && !is_static_string<T>;
 
    // static string; very like `string_t`, but with a fixed max capacity
    template <class T>
    concept static_string_t = str_t<T> && !string_view_t<T> &&
-                             (has_assign<T> || (resizable<T> && has_data<T>) || has_append<T>)&&is_static_string<T>;
+                             (has_assign<T> || (resizable<T> && has_data<T>) || has_append<T>) && is_static_string<T>;
 
    template <class T>
    concept char_array_t = str_t<T> && std::is_array_v<std::remove_pointer_t<std::remove_reference_t<T>>>;
@@ -252,7 +254,7 @@ namespace glz
    };
 
    template <class T>
-   concept array_t = (!meta_value_t<T> && !str_t<T> && !(readable_map_t<T> || writable_map_t<T>)&&range<T>);
+   concept array_t = (!meta_value_t<T> && !str_t<T> && !(readable_map_t<T> || writable_map_t<T>) && range<T>);
 
    template <class T>
    concept readable_array_t =
@@ -338,9 +340,7 @@ namespace glz
    template <class T>
    concept nullable_t = !meta_value_t<T> && !str_t<T> && requires(T t) {
       bool(t);
-      {
-         *t
-      };
+      { *t };
    };
 
    template <class T>
@@ -350,9 +350,7 @@ namespace glz
    template <class T>
    concept nullable_value_t = !meta_value_t<T> && requires(T t) {
       t.value();
-      {
-         t.has_value()
-      } -> std::convertible_to<bool>;
+      { t.has_value() } -> std::convertible_to<bool>;
    };
 
    template <class T>
@@ -377,6 +375,9 @@ namespace glz
    template <class T>
    concept glaze_enum_t = glaze_t<T> && is_specialization_v<meta_wrapper_t<T>, detail::Enum>;
 
+   template <class T>
+   concept is_named_enum = ((glaze_enum_t<T> || (meta_keys<T> && std::is_enum_v<T>)) && !custom_read<T>);
+
    template <class T>
    concept glaze_flags_t = glaze_t<T> && is_specialization_v<meta_wrapper_t<T>, detail::Flags>;
 
@@ -604,6 +605,7 @@ struct glz::meta<glz::error_code>
                                     "invalid_variant_string",
                                     "no_matching_variant_type",
                                     "expected_true_or_false",
+                                    "constraint_violated",
                                     "key_not_found",
                                     "unknown_key",
                                     "missing_key",
@@ -668,6 +670,7 @@ struct glz::meta<glz::error_code>
                                      invalid_variant_string, //
                                      no_matching_variant_type, //
                                      expected_true_or_false, //
+                                     constraint_violated, //
                                      // Key errors
                                      key_not_found, //
                                      unknown_key, //
